==> u_team_core-common-1.20.1-5.1.4.336-sources.jar: info/u_team/u_team_core/util/TagUtil.java <==
package info.u_team.u_team_core.util;

import net.minecraft.class_1299;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3611;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import net.minecraft.class_7924;

public class TagUtil {
	
	public static class_6862<class_2248> createBlockTag(String modid, String name) {
		return createBlockTag(new class_2960(modid, name));
	}
	
	public static class_6862<class_2248> createBlockTag(class_2960 location) {
		return createTag(class_7924.field_41254, location);
	}
	
	public static class_6862<class_1792> createItemTag(String modid, String name) {
		return createItemTag(new class_2960(modid, name));
	}
	
	public static class_6862<class_1792> createItemTag(class_2960 location) {
		return createTag(class_7924.field_41197, location);
	}
	
	public static class_6862<class_3611> createFluidTag(String modid, String name) {
		return createFluidTag(new class_2960(modid, name));
	}
	
	public static class_6862<class_3611> createFluidTag(class_2960 location) {
		return createTag(class_7924.field_41270, location);
	}
	
	public static class_6862<class_1299<?>> createEntityTypeTag(String modid, String name) {
		return createEntityTypeTag(new class_2960(modid, name));
	}
	
	public static class_6862<class_1299<?>> createEntityTypeTag(class_2960 location) {
		return createTag(class_7924.field_41266, location);
	}
	
	public static <T> class_6862<T> createTag(class_5321<? extends class_2378<T>> key, class_2960 location) {
		return class_6862.method_40092(key, location);
	}
	
	public static class_6862<class_2248> fromItemTag(class_6862<class_1792> block) {
		return createBlockTag(block.comp_327());
	}
	
	public static class_6862<class_1792> fromBlockTag(class_6862<class_2248> block) {
		return createItemTag(block.comp_327());
	}
}

==> u_team_core-common-1.21.1-5.6.2.384-sources.jar: info/u_team/u_team_core/util/TagUtil.java <==
package info.u_team.u_team_core.util;

import net.minecraft.class_1299;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3611;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import net.minecraft.class_7924;

public class TagUtil {
	
	public static class_6862<class_2248> createBlockTag(String modid, String name) {
		return createBlockTag(class_2960.method_60655(modid, name));
	}
	
	public static class_6862<class_2248> createBlockTag(class_2960 location) {
		return createTag(class_7924.field_41254, location);
	}
	
	public static class_6862<class_1792> createItemTag(String modid, String name) {
		return createItemTag(class_2960.method_60655(modid, name));
	}
	
	public static class_6862<class_1792> createItemTag(class_2960 location) {
		return createTag(class_7924.field_41197, location);
	}
	
	public static class_6862<class_3611> createFluidTag(String modid, String name) {
		return createFluidTag(class_2960.method_60655(modid, name));
	}
	
	public static class_6862<class_3611> createFluidTag(class_2960 location) {
		return createTag(class_7924.field_41270, location);
	}
	
	public static class_6862<class_1299<?>> createEntityTypeTag(String modid, String name) {
		return createEntityTypeTag(class_2960.method_60655(modid, name));
	}
	
	public static class_6862<class_1299<?>> createEntityTypeTag(class_2960 location) {
		return createTag(class_7924.field_41266, location);
	}
	
	public static <T> class_6862<T> createTag(class_5321<? extends class_2378<T>> key, class_2960 location) {
		return class_6862.method_40092(key, location);
	}
	
	public static class_6862<class_2248> fromItemTag(class_6862<class_1792> block) {
		return createBlockTag(block.comp_327());
	}
	
	public static class_6862<class_1792> fromBlockTag(class_6862<class_2248> block) {
		return createItemTag(block.comp_327());
	}
}
